@@ -1,11 +1,8 @@
-# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
-
 __license__ = 'GPL 3'
 __copyright__ = '2009, Kovid Goyal <kovid@kovidgoyal.net>'
 __docformat__ = 'restructuredtext en'
 
 from calibre.customize import Plugin as _Plugin
-from polyglot.builtins import zip
 
 FONT_SIZES = [('xx-small', 1),
               ('x-small',  None),
@@ -32,8 +29,8 @@ class Plugin(_Plugin):
         self.fsizes = []
         for (name, num), size in zip(FONT_SIZES, fsizes):
             self.fsizes.append((name, num, float(size)))
-        self.fnames = dict((name, sz) for name, _, sz in self.fsizes if name)
-        self.fnums = dict((num, sz) for _, num, sz in self.fsizes if num)
+        self.fnames = {name: sz for name, _, sz in self.fsizes if name}
+        self.fnums = {num: sz for _, num, sz in self.fsizes if num}
         self.width_pts = self.width * 72./self.dpi
         self.height_pts = self.height * 72./self.dpi
 
@@ -457,7 +454,7 @@ class TabletOutput(iPadOutput):
     description = _('Intended for generic tablet devices, does no resizing of images')
 
     screen_size = (10000, 10000)
-    comic_screen_size = (10000, 10000)
+    comic_screen_size = screen_size
 
 
 class SamsungGalaxy(TabletOutput):
@@ -487,7 +484,7 @@ class SonyReaderOutput(OutputProfile):
     dpi                       = 168.451
     fbase                     = 12
     fsizes                    = [7.5, 9, 10, 12, 15.5, 20, 22, 24]
-    unsupported_unicode_chars = [u'\u201f', u'\u201b']
+    unsupported_unicode_chars = ['\u201f', '\u201b']
 
     epub_periodical_format = 'sony'
     # periodical_date_in_title = False
@@ -564,7 +561,7 @@ class GenericEinkHD(GenericEink):
     description = _('Suitable for use with any modern high resolution e-ink device')
 
     screen_size = (10000, 10000)
-    comic_screen_size = (10000, 10000)
+    comic_screen_size = screen_size
 
 
 class JetBook5Output(OutputProfile):
@@ -745,7 +742,7 @@ class KindleOasisOutput(KindlePaperWhite3Output):
 
     name = 'Kindle Oasis'
     short_name = 'kindle_oasis'
-    description = _('This profile is intended for the Amazon Kindle Oasis 2017 and above')
+    description = _('This profile is intended for the Amazon Kindle Oasis 2017, PaperWhite 2021 and above')
     # Screen size is currently just the spec size, actual renderable area will
     # depend on someone with the device doing tests.
     screen_size               = (1264, 1680)
