@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:fdm=marker:ai
 
 
 __license__   = 'GPL v3'
@@ -439,9 +438,9 @@ class DeviceListGroupBox(DeviceOptionsGroupBox):
 
         self.show_previews_checkbox = create_checkbox(
                              _('Show previews'),
-                             _('Kobo previews are included on the Touch and some other versions'
-                               ' by default they are no longer displayed as there is no good reason to '
-                               'see them.  Enable if you wish to see/delete them.'),
+                             _('Kobo previews are included on the Touch and some other versions.'
+                               ' By default, they are no longer displayed as there is no good reason to '
+                               'see them. Enable if you wish to see/delete them.'),
                              device.get_pref('show_previews')
                              )
 
@@ -586,7 +585,7 @@ class MetadataGroupBox(DeviceOptionsGroupBox):
     def edit_template(self):
         t = TemplateDialog(self, self.template)
         t.setWindowTitle(_('Edit template'))
-        if t.exec_():
+        if t.exec():
             self.t.setText(t.rule[1])
 
     def validate(self):
@@ -646,7 +645,7 @@ class TemplateConfig(QWidget):  # {{{
     def edit_template(self):
         t = TemplateDialog(self, self.template)
         t.setWindowTitle(_('Edit template'))
-        if t.exec_():
+        if t.exec():
             self.t.setText(t.rule[1])
 
     def validate(self):
@@ -686,6 +685,6 @@ if __name__ == '__main__':
     d.l.addWidget(bb)
     bb.accepted.connect(d.accept)
     bb.rejected.connect(d.reject)
-    if d.exec_() == QDialog.DialogCode.Accepted:
+    if d.exec() == QDialog.DialogCode.Accepted:
         cw.commit()
     dev.shutdown()
