@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:fdm=marker:ai
 
 
 __license__   = 'GPL v3'
@@ -12,6 +11,12 @@ from calibre.constants import iswindows
 from polyglot.builtins import iteritems
 
 
+supernote_settings = {
+    'calibre_file_paths': {'metadata':'Document/metadata.calibre', 'driveinfo':'Document/driveinfo.calibre'},
+    'send_to': ['Document', 'Documents'],
+}
+
+
 class DeviceDefaults:
 
     def __init__(self):
@@ -30,6 +35,9 @@ class DeviceDefaults:
                     'eBooks/import', 'eBooks', 'sdcard/ebooks'],
                     }
                 ),
+                # Supernote A5 and A5X
+                ({'vendor': 0x2207, 'product': 0x0031}, supernote_settings),
+                ({'vendor': 0x2207, 'product': 0x0011}, supernote_settings),
         )
 
     def __call__(self, device, driver):
