@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=utf-8
 
 
 __license__ = 'GPL v3'
@@ -64,7 +63,7 @@ class Location:
         self.location_node, self.node_item, self.sourceline = location_node, node_item, location_node.sourceline
 
     def __repr__(self):
-        return '%s @ %s:%s' % (self.original_word, self.file_name, self.sourceline)
+        return f'{self.original_word} @ {self.file_name}:{self.sourceline}'
     __str__ = __repr__
 
     def replace(self, new_word):
@@ -164,21 +163,37 @@ opf_spell_tags = {'title', 'creator', 'subject', 'description', 'publisher'}
 
 def read_words_from_opf(root, words, file_name, book_locale):
     for tag in root.iterdescendants('*'):
-        if tag.text is not None and barename(tag.tag) in opf_spell_tags:
+        if barename(tag.tag) in opf_spell_tags:
             if barename(tag.tag) == 'description':
-                add_words_from_escaped_html(tag.text, words, file_name, tag, 'text', book_locale)
+                if tag.text:
+                    add_words_from_escaped_html(tag.text, words, file_name, tag, 'text', book_locale)
+                for child in tag:
+                    if child.tail:
+                        add_words_from_escaped_html(child.tail, words, file_name, child, 'tail', book_locale)
             else:
-                add_words_from_text(tag, 'text', words, file_name, book_locale)
+                if tag.text:
+                    add_words_from_text(tag, 'text', words, file_name, book_locale)
+                for child in tag:
+                    if child.tail:
+                        add_words_from_text(child, 'tail', words, file_name, book_locale)
         add_words_from_attr(tag, _opf_file_as, words, file_name, book_locale)
 
 
 def count_chars_in_opf(root, counter, file_name, book_locale):
     for tag in root.iterdescendants('*'):
-        if tag.text is not None and barename(tag.tag) in opf_spell_tags:
+        if barename(tag.tag) in opf_spell_tags:
             if barename(tag.tag) == 'description':
-                count_chars_in_escaped_html(tag.text, counter, file_name, tag, 'text', book_locale)
+                if tag.text:
+                    count_chars_in_escaped_html(tag.text, counter, file_name, tag, 'text', book_locale)
+                for child in tag:
+                    if child.tail:
+                        count_chars_in_escaped_html(child.tail, counter, file_name, tag, 'tail', book_locale)
             else:
-                count_chars_in_text(tag, 'text', counter, file_name, book_locale)
+                if tag.text:
+                    count_chars_in_text(tag, 'text', counter, file_name, book_locale)
+                for child in tag:
+                    if child.tail:
+                        count_chars_in_text(tag, 'tail', counter, file_name, book_locale)
         count_chars_in_attr(tag, _opf_file_as, counter, file_name, book_locale)
 
 
@@ -202,7 +217,7 @@ html_spell_tags = {'script', 'style', 'link'}
 
 
 def read_words_from_html_tag(tag, words, file_name, parent_locale, locale):
-    if tag.text is not None and barename(tag.tag) not in html_spell_tags:
+    if tag.text is not None and isinstance(tag.tag, str) and barename(tag.tag) not in html_spell_tags:
         add_words_from_text(tag, 'text', words, file_name, locale)
     for attr in {'alt', 'title'}:
         add_words_from_attr(tag, attr, words, file_name, locale)
@@ -211,7 +226,7 @@ def read_words_from_html_tag(tag, words, file_name, parent_locale, locale):
 
 
 def count_chars_in_html_tag(tag, counter, file_name, parent_locale, locale):
-    if tag.text is not None and barename(tag.tag) not in html_spell_tags:
+    if tag.text is not None and isinstance(tag.tag, str) and barename(tag.tag) not in html_spell_tags:
         count_chars_in_text(tag, 'text', counter, file_name, locale)
     for attr in {'alt', 'title'}:
         count_chars_in_attr(tag, attr, counter, file_name, locale)
@@ -220,14 +235,15 @@ def count_chars_in_html_tag(tag, counter, file_name, parent_locale, locale):
 
 
 def locale_from_tag(tag):
-    if 'lang' in tag.attrib:
+    a = tag.attrib
+    if 'lang' in a:
         try:
             loc = parse_lang_code(tag.get('lang'))
         except ValueError:
             loc = None
         if loc is not None:
             return loc
-    if '{http://www.w3.org/XML/1998/namespace}lang' in tag.attrib:
+    if '{http://www.w3.org/XML/1998/namespace}lang' in a:
         try:
             loc = parse_lang_code(tag.get('{http://www.w3.org/XML/1998/namespace}lang'))
         except ValueError:
@@ -242,7 +258,7 @@ def read_words_from_html(root, words, file_name, book_locale):
         parent, parent_locale = stack.pop()
         locale = locale_from_tag(parent) or parent_locale
         read_words_from_html_tag(parent, words, file_name, parent_locale, locale)
-        stack.extend((tag, locale) for tag in parent.iterchildren('*'))
+        stack.extend((tag, locale) for tag in parent)
 
 
 def count_chars_in_html(root, counter, file_name, book_locale):
@@ -251,7 +267,7 @@ def count_chars_in_html(root, counter, file_name, book_locale):
         parent, parent_locale = stack.pop()
         locale = locale_from_tag(parent) or parent_locale
         count_chars_in_html_tag(parent, counter, file_name, parent_locale, locale)
-        stack.extend((tag, locale) for tag in parent.iterchildren('*'))
+        stack.extend((tag, locale) for tag in parent)
 
 
 def group_sort(locations):
@@ -275,14 +291,24 @@ def get_checkable_file_names(container):
     return file_names, ncx_toc
 
 
-def get_all_words(container, book_locale, get_word_count=False):
+def root_is_excluded_from_spell_check(root):
+    for child in root:
+        q = (getattr(child, 'text', '') or '').strip().lower()
+        if q == 'calibre-no-spell-check':
+            return True
+    return False
+
+
+def get_all_words(container, book_locale, get_word_count=False, excluded_files=()):
     words = defaultdict(list)
     words[None] = 0
     file_names, ncx_toc = get_checkable_file_names(container)
     for file_name in file_names:
-        if not container.exists(file_name):
+        if not container.exists(file_name) or file_name in excluded_files:
             continue
         root = container.parsed(file_name)
+        if root_is_excluded_from_spell_check(root):
+            continue
         if file_name == container.opf_name:
             read_words_from_opf(root, words, file_name, book_locale)
         elif file_name == ncx_toc:
