@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=utf-8
 # License: GPL v3 Copyright: 2019, Kovid Goyal <kovid at kovidgoyal.net>
 
 
@@ -104,7 +103,7 @@ def main(path_to_html, tdir, image_format='jpeg'):
     os.chdir(tdir)
     renderer = Render()
     renderer.start_load(path_to_html)
-    ret = QApplication.instance().exec_()
+    ret = QApplication.instance().exec()
     if ret == 0:
         page_images('rendered.pdf', image_format=image_format)
         ext = {'jpeg': 'jpg'}.get(image_format, image_format)
