@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=utf-8
 # License: GPLv3 Copyright: 2015, Kovid Goyal <kovid at kovidgoyal.net>
 
 
@@ -42,7 +41,7 @@ class AuthorMapAction(InterfaceAction):
             'The changes will be applied to <b>one book in the library</b>',
             'The changes will be applied to <b>{} books in the library</b>', len(book_ids))
         d.edit_widget.msg_label.setText(d.edit_widget.msg_label.text() + '<p>' + txt.format(len(book_ids)))
-        if d.exec_() != QDialog.DialogCode.Accepted:
+        if d.exec() != QDialog.DialogCode.Accepted:
             return
         with BusyCursor():
             rules = d.rules
