@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
 
 
 __license__   = 'GPL v3'
@@ -150,7 +149,7 @@ class ConvertAction(InterfaceAction):
         if not rows or len(rows) == 0:
             d = error_dialog(self.gui, _('Cannot convert'),
                     _('No books selected'))
-            d.exec_()
+            d.exec()
             return None
         return [self.gui.library_view.model().db.id(r) for r in rows]
 
