@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=utf-8
 
 
 __license__ = 'GPL v3'
@@ -110,7 +109,7 @@ class EmbedAction(InterfaceAction):
                 tc.setVisible(True), tc.setText(_('Show the &failed books in the main book list'))
                 tc.setChecked(gprefs.get('show-embed-failed-books', False))
                 d.resize_needed.emit()
-                d.exec_()
+                d.exec()
                 gprefs['show-embed-failed-books'] = tc.isChecked()
                 if tc.isChecked():
                     failed_ids = {mi.book_id for mi, fmt, tb in errors}
