@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
 
 
 __license__   = 'GPL v3'
@@ -30,6 +29,6 @@ class PluginUpdaterAction(InterfaceAction):
             initial_filter = FILTER_ALL
 
         d = PluginUpdaterDialog(self.gui, initial_filter=initial_filter)
-        d.exec_()
+        d.exec()
         if d.do_restart:
             self.gui.quit(restart=True)
