@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
 
 
 __license__   = 'GPL v3'
@@ -29,7 +28,7 @@ class ShowBookDetailsAction(InterfaceAction):
         if self.gui.current_view() is not self.gui.library_view:
             error_dialog(self.gui, _('No detailed info available'),
                 _('No detailed information is available for books '
-                  'on the device.')).exec_()
+                  'on the device.')).exec()
             return
         index = self.gui.library_view.currentIndex()
         if index.isValid():
