@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:fdm=marker:ai
 
 
 __license__   = 'GPL v3'
@@ -130,7 +129,7 @@ class ToCEditAction(InterfaceAction):
         if not rows or len(rows) == 0:
             d = error_dialog(self.gui, _('Cannot edit ToC'),
                     _('No books selected'))
-            d.exec_()
+            d.exec()
             return None
         db = self.gui.current_db
         ans = (db.id(r) for r in rows)
@@ -140,7 +139,7 @@ class ToCEditAction(InterfaceAction):
         for book_id, fmts in iteritems(book_id_map):
             if len(fmts) > 1:
                 d = ChooseFormat(fmts, self.gui)
-                if d.exec_() != QDialog.DialogCode.Accepted:
+                if d.exec() != QDialog.DialogCode.Accepted:
                     return
                 fmts = d.formats
             for fmt in fmts:
@@ -160,12 +159,19 @@ class ToCEditAction(InterfaceAction):
     def check_for_completions(self):
         from calibre.utils.filenames import retry_on_fail
         for job in tuple(self.jobs):
-            started_path = job['path'] + '.started'
-            result_path = job['path'] + '.result'
+            path = job['path']
+            started_path = path + '.started'
+            result_path = path + '.result'
             if job['started'] and os.path.exists(result_path):
                 self.jobs.remove(job)
-                with open(result_path) as f:
-                    ret = int(f.read().strip())
+                ret = -1
+
+                def read(result_path):
+                    nonlocal ret
+                    with open(result_path) as f:
+                        ret = int(f.read().strip())
+
+                retry_on_fail(read, result_path)
                 retry_on_fail(os.remove, result_path)
                 if ret == 0:
                     db = self.gui.current_db
@@ -174,11 +180,13 @@ class ToCEditAction(InterfaceAction):
                             'Cannot save changes made to {0} by the ToC editor as'
                             ' the calibre library has changed.').format(job['title']), show=True)
                     else:
-                        db.new_api.add_format(job['book_id'], job['fmt'], job['path'], run_hooks=False)
-                os.remove(job['path'])
+                        db.new_api.add_format(job['book_id'], job['fmt'], path, run_hooks=False)
+                retry_on_fail(os.remove, path)
             else:
                 if monotonic() - job['start_time'] > 120:
                     self.jobs.remove(job)
+                    error_dialog(self.gui, _('Failed to start editor'), _(
+                        'Could not edit: {}. The Table of Contents editor did not start in four minutes').format(job['title']), show=True)
                     continue
                 if os.path.exists(started_path):
                     job['started'] = True
