@@ -12,7 +12,7 @@ from functools import partial
 from qt.core import (
     Qt, QDialog, QAbstractItemView, QTableWidgetItem, QIcon, QListWidgetItem,
     QCoreApplication, QEvent, QObject, QApplication, pyqtSignal, QByteArray, QMenu,
-    QShortcut, QTimer)
+    QShortcut, QTimer, QStyle)
 
 from calibre.customize.ui import find_plugin
 from calibre.gui2 import gprefs
@@ -263,6 +263,8 @@ class Quickview(QDialog, Ui_Quickview):
 
         self.close_button.setDefault(False)
         self.close_button_tooltip = _('The Quickview shortcut ({0}) shows/hides the Quickview panel')
+        self.refresh_button.setIcon(QIcon.ic('view-refresh.png'))
+        self.close_button.setIcon(self.style().standardIcon(QStyle.StandardPixmap.SP_DialogCloseButton))
         if self.is_pane:
             self.dock_button.setText(_('Undock'))
             self.dock_button.setToolTip(_('Show the Quickview panel in its own floating window'))
@@ -666,7 +668,7 @@ class Quickview(QDialog, Ui_Quickview):
             elif col == 'size':
                 v = mi.get('book_size')
                 if v is not None:
-                    return ('{:n}'.format(v), v, 0)
+                    return (f'{v:n}', v, 0)
                 else:
                     return ('', None, 0)
             elif self.fm[col]['datatype'] == 'series':
@@ -785,8 +787,7 @@ class Quickview(QDialog, Ui_Quickview):
             self.book_not_in_view_error()
             return
         key = self.column_order[column]
-        modifiers = int(QApplication.keyboardModifiers())
-        if modifiers in (Qt.Modifier.CTRL, Qt.Modifier.SHIFT):
+        if QApplication.keyboardModifiers() in (Qt.KeyboardModifier.ControlModifier, Qt.KeyboardModifier.ShiftModifier):
             self.edit_metadata(book_id)
         else:
             self.view.select_cell(self.db.data.id_to_index(book_id),
