@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
 # License: GPLv3 Copyright: 2011, Kovid Goyal <kovid at kovidgoyal.net>
 
 
@@ -111,7 +110,7 @@ def restore_database(db, parent=None):
         return False
     db.close()
     d = DBRestore(parent, db.library_path)
-    d.exec_()
+    d.exec()
     r = d.restorer
     d.restorer = None
     if d.rejected:
@@ -127,7 +126,7 @@ def restore_database(db, parent=None):
 
 def repair_library_at(library_path, parent=None, wait_time=2):
     d = DBRestore(parent, library_path, wait_time=wait_time)
-    d.exec_()
+    d.exec()
     if d.rejected:
         return False
     r = d.restorer
