@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=utf-8
 # License: GPLv3 Copyright: 2008, Kovid Goyal <kovid at kovidgoyal.net>
 
 
@@ -323,7 +322,7 @@ class TagListEditor(QDialog, Ui_TagListEditor):
             action_title_case.triggered.connect(partial(self.do_case, titlecase))
             action_capitalize.triggered.connect(partial(self.do_case, capitalize))
             m.addMenu(case_menu)
-        m.exec_(self.table.mapToGlobal(point))
+        m.exec(self.table.mapToGlobal(point))
 
     def search_for_books(self, item):
         from calibre.gui2.ui import get_gui
@@ -377,7 +376,7 @@ class TagListEditor(QDialog, Ui_TagListEditor):
             r = self.search_item_row = (self.search_item_row + 1) % self.table.rowCount()
             if self.string_contains(find_text, self.table.item(r, 0).text()):
                 self.table.setCurrentItem(self.table.item(r, 0))
-                self.table.setFocus(True)
+                self.table.setFocus(Qt.FocusReason.OtherFocusReason)
                 return
         # Nothing found. Pop up the little dialog for 1.5 seconds
         self.not_found_label.setVisible(True)
@@ -468,7 +467,7 @@ class TagListEditor(QDialog, Ui_TagListEditor):
 
         if select_item is not None:
             self.table.setCurrentItem(select_item)
-            self.table.setFocus(True)
+            self.table.setFocus(Qt.FocusReason.OtherFocusReason)
             self.start_find_pos = select_item.row()
         else:
             self.table.setCurrentCell(0, 0)
@@ -564,7 +563,7 @@ class TagListEditor(QDialog, Ui_TagListEditor):
         indexes = self.table.selectionModel().selectedRows()
         if not indexes:
             error_dialog(self, _('No item selected'),
-                         _('You must select one item from the list of available items.')).exec_()
+                         _('You must select one item from the list of available items.')).exec()
             return
 
         if not confirm(
@@ -589,7 +588,7 @@ class TagListEditor(QDialog, Ui_TagListEditor):
     def _rename_tag(self, item):
         if item is None:
             error_dialog(self, _('No item selected'),
-                         _('You must select one item from the list of available items.')).exec_()
+                         _('You must select one item from the list of available items.')).exec()
             return
         for col_zero_item in self.table.selectedItems():
             if col_zero_item.is_deleted:
@@ -616,7 +615,7 @@ class TagListEditor(QDialog, Ui_TagListEditor):
         deletes = self.table.selectedItems()
         if not deletes:
             error_dialog(self, _('No items selected'),
-                         _('You must select at least one item from the list.')).exec_()
+                         _('You must select at least one item from the list.')).exec()
             return
 
         to_del = []
