@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
 
 
 __license__   = 'GPL v3'
@@ -34,7 +33,7 @@ class TemplateLineEditor(QLineEdit):
         action_clear_field.triggered.connect(self.clear_field)
         action_open_editor = menu.addAction(_('Open template editor'))
         action_open_editor.triggered.connect(self.open_editor)
-        menu.exec_(event.globalPos())
+        menu.exec(event.globalPos())
 
     def clear_field(self):
         self.setText('')
@@ -42,5 +41,5 @@ class TemplateLineEditor(QLineEdit):
     def open_editor(self):
         t = TemplateDialog(self, self.text(), mi=self.mi)
         t.setWindowTitle(_('Edit template'))
-        if t.exec_():
+        if t.exec():
             self.setText(t.rule[1])
