@@ -1,10 +1,9 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=utf-8
 # License: GPLv3 Copyright: 2017, Kovid Goyal <kovid at kovidgoyal.net>
 
 
 from qt.core import (
-    QFontMetrics, QHBoxLayout, QIcon, QMenu, QPainter, QPushButton, QSize,
+    QFontMetrics, QHBoxLayout, QIcon, QMenu, QStylePainter, QPushButton, QSize,
     QSizePolicy, Qt, QWidget, QStyleOption, QStyle, QEvent)
 
 
@@ -56,13 +55,13 @@ class LayoutItem(QWidget):
     def paintEvent(self, ev):
         shown = self.button.isChecked()
         ls = self.fm.lineSpacing()
-        painter = QPainter(self)
+        painter = QStylePainter(self)
         if self.mouse_over:
             tool = QStyleOption()
+            tool.initFrom(self)
             tool.rect = self.rect()
             tool.state = QStyle.StateFlag.State_Raised | QStyle.StateFlag.State_Active | QStyle.StateFlag.State_MouseOver
-            s = self.style()
-            s.drawPrimitive(QStyle.PrimitiveElement.PE_PanelButtonTool, tool, painter, self)
+            painter.drawPrimitive(QStyle.PrimitiveElement.PE_PanelButtonTool, tool)
         painter.drawText(
             0, 0,
             self.width(),
@@ -142,4 +141,4 @@ if __name__ == '__main__':
     app = Application([])
     w = LayoutMenu()
     w.show()
-    w.exec_()
+    w.exec()
