@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
 
 
 __license__   = 'GPL v3'
@@ -69,4 +68,4 @@ class DebugDevice(QDialog):
 if __name__ == '__main__':
     app = QApplication([])
     d = DebugDevice()
-    d.exec_()
+    d.exec()
