@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
 
 
 __license__   = 'GPL v3'
@@ -17,7 +16,7 @@ def step_dialog(parent, title, msg, det_msg=''):
     d.setWindowTitle(title)
     d.setText(msg)
     d.setStandardButtons(QMessageBox.StandardButton.Ok | QMessageBox.StandardButton.Cancel)
-    return d.exec_() & QMessageBox.StandardButton.Cancel
+    return d.exec() & QMessageBox.StandardButton.Cancel
 
 
 class UserDefinedDevice(QDialog):
@@ -96,4 +95,4 @@ class UserDefinedDevice(QDialog):
 if __name__ == '__main__':
     app = QApplication([])
     d = UserDefinedDevice()
-    d.exec_()
+    d.exec()
