@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
 # License: GPLv3 Copyright: 2010, Kovid Goyal <kovid at kovidgoyal.net>
 
 import errno
@@ -57,7 +56,7 @@ if iswindows and not isportable:
         if args:
             quoted_args = []
             for arg in args:
-                quoted_args.append('"{}"'.format(arg))
+                quoted_args.append(f'"{arg}"')
             quoted_args = ' '.join(quoted_args)
         winutil.manage_shortcut(shortcut_path, target, description, quoted_args)
 
@@ -183,7 +182,7 @@ class Path(QWidget):
         self.l = l = QHBoxLayout(self)
         l.setContentsMargins(0, 0, 0, 0)
         self.text = t = HistoryLineEdit(self)
-        t.initialize('server-opts-{}'.format(name))
+        t.initialize(f'server-opts-{name}')
         t.setClearButtonEnabled(True)
         t.currentTextChanged.connect(self.changed_signal.emit)
         l.addWidget(t)
@@ -217,7 +216,7 @@ class Choices(QComboBox):
         self.setEditable(False)
         opt = options[name]
         self.choices = opt.choices
-        tuple(map(self.addItem, opt.choices))
+        self.addItems(opt.choices)
         self.currentIndexChanged.connect(self.changed_signal.emit)
         init_opt(self, opt, layout)
 
@@ -740,7 +739,7 @@ class User(QWidget):
 
     def change_password(self):
         d = NewUser(self.user_data, self, self.username)
-        if d.exec_() == QDialog.DialogCode.Accepted:
+        if d.exec() == QDialog.DialogCode.Accepted:
             self.user_data[self.username]['pw'] = d.password
             self.changed_signal.emit()
 
@@ -797,7 +796,7 @@ class User(QWidget):
             self.user_data[self.username]['restriction'].copy(),
             parent=self
         )
-        if d.exec_() == QDialog.DialogCode.Accepted:
+        if d.exec() == QDialog.DialogCode.Accepted:
             self.user_data[self.username]['restriction'] = d.restriction
             self.update_restriction()
             self.changed_signal.emit()
@@ -861,7 +860,7 @@ class Users(QWidget):
 
     def add_user(self):
         d = NewUser(self.user_data, parent=self)
-        if d.exec_() == QDialog.DialogCode.Accepted:
+        if d.exec() == QDialog.DialogCode.Accepted:
             un, pw = d.username, d.password
             self.user_data[un] = create_user_data(pw)
             self.user_list.insertItem(0, un)
@@ -1273,7 +1272,7 @@ class ConfigWidget(ConfigWidgetBase):
                     self,
                     _('Failed to start Content server'),
                     as_unicode(self.gui.content_server.exception)
-                ).exec_()
+                ).exec()
                 self.gui.content_server = None
                 return
             self.main_tab.update_button_state()
@@ -1289,7 +1288,7 @@ class ConfigWidget(ConfigWidgetBase):
             show_copy_button=False
         )
         QTimer.singleShot(500, self.check_exited)
-        self.stopping_msg.exec_()
+        self.stopping_msg.exec()
 
     def check_exited(self):
         if getattr(self.server, 'is_running', False):
