@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
 # License: GPLv3 Copyright: 2010, Kovid Goyal <kovid at kovidgoyal.net>
 
 import copy
@@ -7,7 +6,7 @@ import json
 import traceback
 from qt.core import QDialog, QDialogButtonBox
 
-from calibre.gui2 import error_dialog, question_dialog, warning_dialog
+from calibre.gui2 import error_dialog, gprefs, question_dialog, warning_dialog
 from calibre.gui2.dialogs.template_dialog import TemplateDialog
 from calibre.gui2.preferences import AbortInitialize, ConfigWidgetBase, test_widget
 from calibre.gui2.preferences.template_functions_ui import Ui_Form
@@ -76,9 +75,12 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         </p>
         ''')
         self.textBrowser.setHtml(help_text)
-        self.textBrowser_showing = True
         self.textBrowser.adjustSize()
         self.show_hide_help_button.clicked.connect(self.show_hide_help)
+        self.textBrowser_showing = not gprefs.get('template_functions_prefs_tf_show_help', True)
+        self.textBrowser_height = self.textBrowser.height()
+        self.show_hide_help()
+
         help_text = _('''
         <p>
         Here you can create, edit (replace), and delete stored templates used
@@ -111,13 +113,15 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         </p>
         ''')
         self.st_textBrowser.setHtml(help_text.format('program:', 'arguments'))
-        self.st_textBrowser_showing = True
         self.st_textBrowser.adjustSize()
         self.st_show_hide_help_button.clicked.connect(self.st_show_hide_help)
+        self.st_textBrowser_height = self.st_textBrowser.height()
+        self.st_textBrowser_showing = not gprefs.get('template_functions_prefs_st_show_help', True)
+        self.st_show_hide_help()
 
     def st_show_hide_help(self):
+        gprefs['template_functions_prefs_st_show_help'] = not self.st_textBrowser_showing
         if self.st_textBrowser_showing:
-            self.st_textBrowser_height = self.st_textBrowser.height()
             self.st_textBrowser.setMaximumHeight(self.st_show_hide_help_button.height())
             self.st_textBrowser_showing = False
             self.st_show_hide_help_button.setText(_('Show help'))
@@ -127,8 +131,8 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
             self.st_show_hide_help_button.setText(_('Hide help'))
 
     def show_hide_help(self):
+        gprefs['template_functions_prefs_tf_show_help'] = not self.textBrowser_showing
         if self.textBrowser_showing:
-            self.textBrowser_height = self.textBrowser.height()
             self.textBrowser.setMaximumHeight(self.show_hide_help_button.height())
             self.textBrowser_showing = False
             self.show_hide_help_button.setText(_('Show help'))
@@ -214,7 +218,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
                 if row.isValid():
                     self.mi.append(db.new_api.get_proxy_metadata(db.data.index_to_id(row.row())))
 
-            self.template_editor.set_mi(self.mi[0], self.fm)
+            self.template_editor.set_mi(self.mi, self.fm)
 
     # Python function tab
 
@@ -281,7 +285,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
                          show=False, show_copy_button=False)
             box.bb.setStandardButtons(box.bb.standardButtons() | QDialogButtonBox.StandardButton.Cancel)
             box.det_msg_toggle.setVisible(False)
-            if not box.exec_():
+            if not box.exec():
                 return
         try:
             prog = str(self.program.toPlainText())
@@ -350,7 +354,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
                    mi=self.mi, fm=self.fm, text_is_placeholder=self.st_first_time,
                    all_functions=all_funcs)
             t.setWindowTitle(_('Template tester'))
-            if t.exec_() == QDialog.DialogCode.Accepted:
+            if t.exec() == QDialog.DialogCode.Accepted:
                 self.st_previous_text = t.rule[1]
                 self.st_first_time = False
         else:
@@ -432,7 +436,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
                 box.bb.setStandardButtons(box.bb.standardButtons() |
                                           QDialogButtonBox.StandardButton.Cancel)
                 box.det_msg_toggle.setVisible(False)
-                if not box.exec_():
+                if not box.exec():
                     self.te_name.blockSignals(True)
                     dex = self.te_name.findText(self.st_current_program_name)
                     self.te_name.setCurrentIndex(dex)
@@ -467,6 +471,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         funcs = compile_user_template_functions(pref_value)
         self.db.new_api.set_user_template_functions(funcs)
         self.gui.library_view.model().refresh()
+        self.gui.library_view.model().research()
         load_user_template_functions(self.db.library_id, [], funcs)
         return False
 
