@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=utf-8
 
 
 __license__ = 'GPL v3'
@@ -152,5 +151,5 @@ class TextureChooser(QDialog):
 if __name__ == '__main__':
     app = QApplication([])  # noqa
     d = TextureChooser()
-    d.exec_()
+    d.exec()
     print(d.texture)
