@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=utf-8
 
 
 __license__ = 'GPL v3'
@@ -111,6 +110,7 @@ class CreateVirtualLibrary(QDialog):  # {{{
         self.vl_name = QComboBox()
         self.vl_name.setEditable(True)
         self.vl_name.lineEdit().setMaxLength(MAX_VIRTUAL_LIBRARY_NAME_LENGTH)
+        self.vl_name.lineEdit().setClearButtonEnabled(True)
         la1.setBuddy(self.vl_name)
         gl.addWidget(self.vl_name, 0, 1)
         self.editing = editing
@@ -122,6 +122,7 @@ class CreateVirtualLibrary(QDialog):  # {{{
         self.la2 = la2 = QLabel(_('&Search expression:'))
         gl.addWidget(la2, 1, 0)
         self.vl_text = QLineEdit()
+        self.vl_text.setClearButtonEnabled(True)
         self.vl_text.textChanged.connect(self.search_text_changed)
         la2.setBuddy(self.vl_text)
         gl.addWidget(self.vl_text, 1, 1)
@@ -245,7 +246,7 @@ class CreateVirtualLibrary(QDialog):  # {{{
         else:
             names = getattr(db, 'all_%s_names'%f)()
         d = SelectNames(names, txt, parent=self)
-        if d.exec_() == QDialog.DialogCode.Accepted:
+        if d.exec() == QDialog.DialogCode.Accepted:
             prefix = f+'s' if f in {'tag', 'author'} else f
             if f == 'search':
                 search = ['(%s)'%(db.saved_search_lookup(x)) for x in d.names]
@@ -358,7 +359,7 @@ class SearchRestrictionMixin:
         db = self.library_view.model().db
         virt_libs = db.new_api.pref('virtual_libraries', {})
         cd = CreateVirtualLibrary(self, virt_libs.keys(), editing=name)
-        if cd.exec_() == QDialog.DialogCode.Accepted:
+        if cd.exec() == QDialog.DialogCode.Accepted:
             if name:
                 self._remove_vl(name, reapply=False)
             self.add_virtual_library(db, cd.library_name, cd.library_search)
@@ -369,7 +370,7 @@ class SearchRestrictionMixin:
     def build_virtual_library_menu(self, m, add_tabs_action=True):
         m.clear()
 
-        a = m.addAction(_('Create Virtual library'))
+        a = m.addAction(QIcon.ic('plus.png'), _('Create Virtual library'))
         a.triggered.connect(partial(self.do_create_edit, name=None))
         db = self.current_db
         virt_libs = db.new_api.pref('virtual_libraries', {})
@@ -377,15 +378,15 @@ class SearchRestrictionMixin:
         a = self.edit_menu
         self.build_virtual_library_list(a, self.do_create_edit)
         if virt_libs:
-            m.addMenu(a)
+            m.addMenu(a).setIcon(QIcon.ic('edit_input.png'))
 
         a = self.rm_menu
         self.build_virtual_library_list(a, self.remove_vl_triggered)
         if virt_libs:
-            m.addMenu(a)
+            m.addMenu(a).setIcon(QIcon.ic('minus.png'))
 
         if virt_libs:
-            m.addAction(_('Quick select Virtual library'), self.choose_vl_triggerred)
+            m.addAction(QIcon.ic('toc.png'), _('Quick select Virtual library'), self.choose_vl_triggerred)
 
         if add_tabs_action:
             if gprefs['show_vl_tabs']:
@@ -521,7 +522,7 @@ class SearchRestrictionMixin:
         d = QuickOpen(
                 sorted(virt_libs.keys(), key=sort_key), parent=self, title=_('Choose Virtual library'),
                 name='vl-open', level1=' ', help_text=help_text)
-        if d.exec_() == QDialog.DialogCode.Accepted and d.selected_result:
+        if d.exec() == QDialog.DialogCode.Accepted and d.selected_result:
             self.apply_virtual_library(library=d.selected_result)
 
     def _remove_vl(self, name, reapply=True):
@@ -672,4 +673,4 @@ if __name__ == '__main__':
     app
     gui = init_gui()
     d = CreateVirtualLibrary(gui, [])
-    d.exec_()
+    d.exec()
