@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=utf-8
 # License: GPLv3 Copyright: 2015, Kovid Goyal <kovid at kovidgoyal.net>
 
 
@@ -35,7 +34,7 @@ class QueryEdit(QLineEdit):
     def contextMenuEvent(self, ev):
         menu = self.createStandardContextMenu()
         self.parent().specialise_context_menu(menu)
-        menu.exec_(ev.globalPos())
+        menu.exec(ev.globalPos())
 
 
 class RuleEdit(QWidget):
@@ -154,7 +153,7 @@ class RuleEdit(QWidget):
     def edit_tags(self):
         from calibre.gui2.dialogs.tag_editor import TagEditor
         d = TagEditor(self, get_gui().current_db, current_tags=list(filter(None, [x.strip() for x in self.query.text().split(',')])))
-        if d.exec_() == QDialog.DialogCode.Accepted:
+        if d.exec() == QDialog.DialogCode.Accepted:
             self.query.setText(', '.join(d.tags))
 
     @property
@@ -251,13 +250,13 @@ class Delegate(QStyledItemDelegate):
         if width and width != st.textWidth():
             st.setTextWidth(width)
         br = st.size()
-        return QSize(br.width() + self.MARGIN, br.height() + self.MARGIN)
+        return QSize(int(br.width() + self.MARGIN), int(br.height() + self.MARGIN))
 
     def paint(self, painter, option, index):
         QStyledItemDelegate.paint(self, painter, option, index)
         pal = option.palette
         color = pal.color(QPalette.ColorRole.HighlightedText if option.state & QStyle.StateFlag.State_Selected else QPalette.ColorRole.Text).name()
-        text = '<div style="color:%s">%s</div>' % (color, index.data(RENDER_ROLE))
+        text = f'<div style="color:{color}">{index.data(RENDER_ROLE)}</div>'
         st = QStaticText(text)
         st.setTextWidth(option.rect.width())
         painter.drawStaticText(option.rect.left() + self.MARGIN // 2, option.rect.top() + self.MARGIN // 2, st)
@@ -321,7 +320,7 @@ class Rules(QWidget):
 
     def add_rule(self):
         d = self.RuleEditDialogClass(self)
-        if d.exec_() == QDialog.DialogCode.Accepted:
+        if d.exec() == QDialog.DialogCode.Accepted:
             i = self.RuleItemClass(d.edit_widget.rule, self.rule_list)
             self.rule_list.scrollToItem(i)
             self.changed.emit()
@@ -331,7 +330,7 @@ class Rules(QWidget):
         if i is not None:
             d = self.RuleEditDialogClass(self)
             d.edit_widget.rule = i.data(Qt.ItemDataRole.UserRole)
-            if d.exec_() == QDialog.DialogCode.Accepted:
+            if d.exec() == QDialog.DialogCode.Accepted:
                 rule = d.edit_widget.rule
                 i.setData(DATA_ROLE, rule)
                 i.setData(RENDER_ROLE, self.RuleItemClass.text_from_rule(rule, self.rule_list))
@@ -525,7 +524,7 @@ class RulesDialog(Dialog, SaveLoadMixin):
         self.edit_widget.rules = rules
 
     def test_rules(self):
-        self.TesterClass(self.rules, self).exec_()
+        self.TesterClass(self.rules, self).exec()
 
     def sizeHint(self):
         ans = super().sizeHint()
@@ -541,7 +540,7 @@ if __name__ == '__main__':
         {'action':'replace', 'query':'moose,sfdg,sfdg,dfsg,dfgsh,sd,er,erg,egrer,ger,s,fgfsgfsga', 'match_type':'one_of', 'replace':'xxxx'},
         {'action':'split', 'query':'/', 'match_type':'has', 'replace':'/'},
     ]
-    d.exec_()
+    d.exec()
     from pprint import pprint
     pprint(d.rules)
     del d, app
