@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=utf-8
 # License: GPLv3 Copyright: 2013, Kovid Goyal <kovid at kovidgoyal.net>
 
 
@@ -189,7 +188,7 @@ class Boss(QObject):
         orig_spell = tprefs['inline_spell_check']
         orig_size = tprefs['toolbar_icon_size']
         p = Preferences(self.gui)
-        ret = p.exec_()
+        ret = p.exec()
         if p.dictionaries_changed:
             dictionaries.clear_caches()
             dictionaries.initialize(force=True)  # Reread user dictionaries
@@ -256,7 +255,7 @@ class Boss(QObject):
         if not self._check_before_open():
             return
         d = NewBook(self.gui)
-        if d.exec_() == QDialog.DialogCode.Accepted:
+        if d.exec() == QDialog.DialogCode.Accepted:
             fmt = d.fmt.lower()
             path = choose_save_file(self.gui, 'edit-book-new-book', _('Choose file location'),
                                     filters=[(fmt.upper(), (fmt,))], all_files=False)
@@ -273,7 +272,7 @@ class Boss(QObject):
         d = ImportForeign(self.gui)
         if hasattr(path, 'rstrip'):
             d.set_src(os.path.abspath(path))
-        if d.exec_() == QDialog.DialogCode.Accepted:
+        if d.exec() == QDialog.DialogCode.Accepted:
             for name in tuple(editors):
                 self.close_editor(name)
             from calibre.ebooks.oeb.polish.import_book import import_book_as_epub
@@ -348,7 +347,7 @@ class Boss(QObject):
         if job.traceback is not None:
             if 'DRMError:' in job.traceback:
                 from calibre.gui2.dialogs.drm_error import DRMErrorMessage
-                return DRMErrorMessage(self.gui).exec_()
+                return DRMErrorMessage(self.gui).exec()
             if 'ObfuscationKeyMissing:' in job.traceback:
                 return error_dialog(self.gui, _('Failed to open book'), _(
                     'Failed to open book, it has obfuscated fonts, but the obfuscation key is missing from the OPF.'
@@ -360,6 +359,7 @@ class Boss(QObject):
         if cn:
             self.save_manager.clear_notify_data()
         self.gui.check_book.clear_at_startup()
+        self.gui.spell_check.clear_caches()
         dictionaries.clear_ignored(), dictionaries.clear_caches()
         parse_worker.clear()
         container = job.result
@@ -391,7 +391,8 @@ class Boss(QObject):
             if ef:
                 if isinstance(ef, str):
                     ef = [ef]
-                tuple(map(self.gui.file_list.request_edit, ef))
+                for i in ef:
+                    self.gui.file_list.request_edit(i)
             else:
                 if tprefs['restore_book_state']:
                     self.restore_book_edit_state()
@@ -484,7 +485,7 @@ class Boss(QObject):
             return
         self.commit_dirty_opf()
         d = NewFileDialog(self.gui)
-        if d.exec_() != QDialog.DialogCode.Accepted:
+        if d.exec() != QDialog.DialogCode.Accepted:
             return
         added_name = self.do_add_file(d.file_name, d.file_data, using_template=d.using_template, edit_file=True)
         if d.file_name.rpartition('.')[2].lower() in ('ttf', 'otf', 'woff'):
@@ -560,7 +561,7 @@ class Boss(QObject):
         d = AddCover(current_container(), self.gui)
         d.import_requested.connect(self.do_add_file)
         try:
-            if d.exec_() == QDialog.DialogCode.Accepted and d.file_name is not None:
+            if d.exec() == QDialog.DialogCode.Accepted and d.file_name is not None:
                 report = []
                 with BusyCursor():
                     self.add_savepoint(_('Before: Add cover'))
@@ -582,7 +583,7 @@ class Boss(QObject):
             return
         self.add_savepoint(_('Before: Edit Table of Contents'))
         d = TOCEditor(title=self.current_metadata.title, parent=self.gui)
-        if d.exec_() != QDialog.DialogCode.Accepted:
+        if d.exec() != QDialog.DialogCode.Accepted:
             self.rewind_savepoint()
             return
         with BusyCursor():
@@ -636,7 +637,7 @@ class Boss(QObject):
         d = RulesDialog(self.gui)
         d.rules = last_used_html_transform_rules
         d.transform_scope = tprefs['html_transform_scope']
-        ret = d.exec_()
+        ret = d.exec()
         last_used_html_transform_rules = d.rules
         scope = d.transform_scope
         tprefs.set('html_transform_scope', scope)
@@ -679,7 +680,7 @@ class Boss(QObject):
         from calibre.ebooks.css_transform_rules import transform_container
         d = RulesDialog(self.gui)
         d.rules = last_used_transform_rules
-        ret = d.exec_()
+        ret = d.exec()
         last_used_transform_rules = d.rules
         if ret != QDialog.DialogCode.Accepted:
             return
@@ -707,7 +708,7 @@ class Boss(QObject):
             self.add_savepoint(_('Before: Get external resources'))
         try:
             d = DownloadResources(self.gui)
-            d.exec_()
+            d.exec()
         except Exception:
             self.rewind_savepoint()
             raise
@@ -742,7 +743,7 @@ class Boss(QObject):
                 _('The %s format does not support file and folder names internally, therefore'
                   ' arranging files into folders is not allowed.') % c.book_type.upper(), show=True)
         d = RationalizeFolders(self.gui)
-        if d.exec_() != QDialog.DialogCode.Accepted:
+        if d.exec() != QDialog.DialogCode.Accepted:
             return
         self.commit_all_editors_to_container()
         name_map = rationalize_folders(c, d.folder_map)
@@ -898,7 +899,7 @@ class Boss(QObject):
         d.b = b = bb.addButton(_('See what &changed'), QDialogButtonBox.ButtonRole.AcceptRole)
         b.setIcon(QIcon(I('diff.png'))), b.setAutoDefault(False)
         bb.button(QDialogButtonBox.StandardButton.Close).setDefault(True)
-        if d.exec_() == QDialog.DialogCode.Accepted:
+        if d.exec() == QDialog.DialogCode.Accepted:
             self.show_current_diff(allow_revert=allow_revert, to_container=to_container)
 
     def compare_book(self):
@@ -1005,11 +1006,11 @@ class Boss(QObject):
             elif action[0] == 'insert_hyperlink':
                 self.commit_all_editors_to_container()
                 d = InsertLink(current_container(), edname, initial_text=ed.get_smart_selection(), parent=self.gui)
-                if d.exec_() == QDialog.DialogCode.Accepted:
+                if d.exec() == QDialog.DialogCode.Accepted:
                     ed.insert_hyperlink(d.href, d.text, template=d.rendered_template)
             elif action[0] == 'insert_tag':
                 d = InsertTag(parent=self.gui)
-                if d.exec_() == QDialog.DialogCode.Accepted:
+                if d.exec() == QDialog.DialogCode.Accepted:
                     ed.insert_tag(d.tag)
             else:
                 ed.action_triggered(action)
@@ -1039,7 +1040,7 @@ class Boss(QObject):
             return error_dialog(self.gui, _('Not supported'), _(
                 'Semantics are not supported for the AZW3 format.'), show=True)
         d = InsertSemantics(c, parent=self.gui)
-        if d.exec_() == QDialog.DialogCode.Accepted and d.changes:
+        if d.exec() == QDialog.DialogCode.Accepted and d.changes:
             self.add_savepoint(_('Before: Set Semantics'))
             d.apply_changes(current_container())
             self.apply_container_update_to_gui()
@@ -1052,7 +1053,7 @@ class Boss(QObject):
         if current_name and c.mime_map[current_name] not in OEB_DOCS | OEB_STYLES:
             current_name = None
         d = FilterCSS(current_name=current_name, parent=self.gui)
-        if d.exec_() == QDialog.DialogCode.Accepted and d.filtered_properties:
+        if d.exec() == QDialog.DialogCode.Accepted and d.filtered_properties:
             self.add_savepoint(_('Before: Filter style information'))
             with BusyCursor():
                 changed = filter_css(current_container(), d.filtered_properties, names=d.filter_names)
@@ -1158,7 +1159,7 @@ class Boss(QObject):
         # Go to the next spelling error
         ed = self.gui.central.current_editor
         name = editor_name(ed)
-        find_next_error(ed, name, self.gui, self.show_editor, self.edit_file)
+        find_next_error(ed, name, self.gui, self.show_editor, self.edit_file, self.close_editor)
 
     def word_change_requested(self, w, new_word):
         if self.commit_all_editors_to_container():
@@ -1367,7 +1368,7 @@ class Boss(QObject):
         if name is None:
             return
         d = MultiSplit(self.gui)
-        if d.exec_() == QDialog.DialogCode.Accepted:
+        if d.exec() == QDialog.DialogCode.Accepted:
             with BusyCursor():
                 self.add_savepoint(_('Before: Split %s') % self.gui.elided_text(name))
                 try:
@@ -1472,6 +1473,7 @@ class Boss(QObject):
         self.apply_container_update_to_gui()
         if master in editors:
             self.show_editor(master)
+        self.gui.message_popup(_('{} files merged').format(len(names)))
 
     @in_thread_job
     def link_stylesheets_requested(self, names, sheets, remove):
@@ -1547,7 +1549,7 @@ class Boss(QObject):
             container = current_container()
             for name, (path, mt) in iteritems(name_map):
                 with lopen(path, 'rb') as f:
-                    container.add_file(name, f.read(), media_type=mt)
+                    container.add_file(name, f.read(), media_type=mt, modify_name_if_needed=True)
             self.apply_container_update_to_gui()
 
     def export_file(self, name, path):
@@ -1592,11 +1594,11 @@ class Boss(QObject):
             return
         from calibre.gui2.tweak_book.polish import show_report, CompressImages, CompressImagesProgress
         d = CompressImages(self.gui)
-        if d.exec_() == QDialog.DialogCode.Accepted:
+        if d.exec() == QDialog.DialogCode.Accepted:
             with BusyCursor():
                 self.add_savepoint(_('Before: compress images'))
                 d = CompressImagesProgress(names=d.names, jpeg_quality=d.jpeg_quality, parent=self.gui)
-                if d.exec_() != QDialog.DialogCode.Accepted:
+                if d.exec() != QDialog.DialogCode.Accepted:
                     self.rewind_savepoint()
                     return
                 changed, report = d.result
@@ -1754,7 +1756,7 @@ class Boss(QObject):
         c = current_container()
         files = [name for name, mime in iteritems(c.mime_map) if c.exists(name) and syntax_from_mime(name, mime) is not None]
         d = QuickOpen(files, parent=self.gui)
-        if d.exec_() == QDialog.DialogCode.Accepted and d.selected_result is not None:
+        if d.exec() == QDialog.DialogCode.Accepted and d.selected_result is not None:
             self.edit_file_requested(d.selected_result, None, c.mime_map[d.selected_result])
 
     # Editor basic controls {{{
@@ -1860,7 +1862,7 @@ class Boss(QObject):
 
     def manage_snippets(self):
         from calibre.gui2.tweak_book.editor.snippets import UserSnippets
-        UserSnippets(self.gui).exec_()
+        UserSnippets(self.gui).exec()
 
     # Shutdown {{{
 
@@ -1911,7 +1913,7 @@ class Boss(QObject):
             b = d.bb.addButton(_('&Quit without saving'), QDialogButtonBox.ButtonRole.ActionRole)
             connect_lambda(b.clicked, d, lambda d: endit(d, False))
             d.resize(d.sizeHint())
-            if d.exec_() != QDialog.DialogCode.Accepted or d.do_save is None:
+            if d.exec() != QDialog.DialogCode.Accepted or d.do_save is None:
                 return False
             if d.do_save:
                 self.gui.action_save.trigger()
