@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=utf-8
 
 
 __license__ = 'GPL v3'
@@ -665,7 +664,7 @@ class CharView(QListView):
                             partial(self.remove_from_favorites, char_code))
                 if self.showing_favorites:
                     m.addAction(_('Restore favorites to defaults'), self.restore_defaults)
-                m.exec_(self.mapToGlobal(pos))
+                m.exec(self.mapToGlobal(pos))
 
     def restore_defaults(self):
         del tprefs['charmap_favorites']
@@ -743,7 +742,7 @@ class CharSelect(Dialog):
         s.addWidget(self.category_view), s.addWidget(self.char_view)
 
         self.char_info = la = QLabel('\xa0')
-        la.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
+        la.setSizePolicy(QSizePolicy.Policy.Ignored, QSizePolicy.Policy.Fixed)
         l.addWidget(la, 2, 0, 1, 3)
 
         self.rearrange_msg = la = QLabel(_(
@@ -794,11 +793,11 @@ class CharSelect(Dialog):
         return QSize(800, 600)
 
     def show_char_info(self, char_code):
+        text = '\xa0'
         if char_code > 0:
             category_name, subcategory_name, character_name = self.category_view.model().get_char_info(char_code)
-            self.char_info.setText('%s - %s - %s (U+%04X)' % (category_name, subcategory_name, character_name, char_code))
-        else:
-            self.char_info.clear()
+            text = _('{character_name} (U+{char_code:04X}) in {category_name} - {subcategory_name}').format(**locals())
+        self.char_info.setText(text)
 
     def show(self):
         self.initialize()
@@ -806,7 +805,7 @@ class CharSelect(Dialog):
         self.raise_()
 
     def char_selected(self, c):
-        if QApplication.keyboardModifiers() & Qt.Modifier.CTRL:
+        if QApplication.keyboardModifiers() & Qt.KeyboardModifier.ControlModifier:
             self.hide()
         if self.parent() is None or self.parent().focusWidget() is None:
             QApplication.clipboard().setText(c)
@@ -829,4 +828,4 @@ if __name__ == '__main__':
     w = CharSelect()
     w.initialize()
     w.show()
-    app.exec_()
+    app.exec()
