@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=utf-8
 
 
 __license__ = 'GPL v3'
@@ -299,7 +298,7 @@ class InsertImage(Dialog):
             n, e = basename.rpartition('.')[0::2]
             basename = n + '.' + e.lower()
             d = ChooseName(basename, self)
-            if d.exec_() == QDialog.DialogCode.Accepted and d.filename:
+            if d.exec() == QDialog.DialogCode.Accepted and d.filename:
                 self.accept()
                 self.chosen_image_is_external = (d.filename, path)
 
@@ -320,7 +319,7 @@ class InsertImage(Dialog):
             return error_dialog(self, _('No image'), _(
                 'There is no image on the clipboard'), show=True)
         d = ChooseName('image.jpg', self)
-        if d.exec_() == QDialog.DialogCode.Accepted and d.filename:
+        if d.exec() == QDialog.DialogCode.Accepted and d.filename:
             fmt = d.filename.rpartition('.')[-1].lower()
             if fmt not in {'jpg', 'jpeg', 'png'}:
                 return error_dialog(self, _('Invalid file extension'), _(
@@ -354,7 +353,7 @@ class InsertImage(Dialog):
 def get_resource_data(rtype, parent):
     if rtype == 'image':
         d = InsertImage(parent)
-        if d.exec_() == QDialog.DialogCode.Accepted:
+        if d.exec() == QDialog.DialogCode.Accepted:
             return d.chosen_image, d.chosen_image_is_external, d.fullpage.isChecked(), d.preserve_aspect_ratio.isChecked()
 
 
@@ -497,4 +496,4 @@ if __name__ == '__main__':
     set_current_container(get_container(sys.argv[-1]))
 
     d = InsertImage(for_browsing=True)
-    d.exec_()
+    d.exec()
