@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=utf-8
 
 
 import importlib
@@ -70,7 +69,7 @@ def _run(args, notify=None):
     parser = option_parser()
     opts, args = parser.parse_args(args)
     decouple('edit-book-'), set_gui_prefs(tprefs)
-    override = 'calibre-edit-book' if islinux else None
+    override = 'calibre-ebook-edit' if islinux else None
     app = Application(args, override_program_name=override, color_prefs=tprefs, windows_app_uid=EDITOR_APP_UID)
     app.file_event_hook = EventAccumulator()
     app.load_builtin_fonts()
@@ -86,7 +85,7 @@ def _run(args, notify=None):
             main.boss.open_book(path)
             break
         app.file_event_hook = main.boss.open_book
-    app.exec_()
+    app.exec()
     # Ensure that the parse worker has quit so that temp files can be deleted
     # on windows
     st = time.time()
