@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
 
 
 __license__   = 'GPL v3'
@@ -963,4 +962,4 @@ def wizard(parent=None):
 if __name__ == '__main__':
     from calibre.gui2 import Application
     app = Application([])
-    wizard().exec_()
+    wizard().exec()
