@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=utf-8
 # License: GPLv3 Copyright: 2016, Kovid Goyal <kovid at kovidgoyal.net>
 
 
@@ -51,7 +50,7 @@ def parse_iso8601(date_string, assume_utc=False, as_utc=True, require_aware=Fals
             description = "%s%02d:%02d" % (sign, abs(tzseconds) // 3600, (abs(tzseconds) % 3600) // 60)
             tz = tzoffset(description, tzseconds)
     elif require_aware:
-        raise ValueError('{} does not specify a time zone'.format(date_string))
+        raise ValueError(f'{date_string} does not specify a time zone')
     dt = dt.replace(tzinfo=tz)
     if as_utc and tz is utc_tz:
         return dt
