@@ -1,5 +1,4 @@
 #!/usr/local/bin/python3.9
-# vim:fileencoding=utf-8
 # License: GPLv3 Copyright: 2017, Kovid Goyal <kovid at kovidgoyal.net>
 
 
@@ -15,6 +14,13 @@ def user_agent_data():
     return ans
 
 
+def common_english_words():
+    ans = getattr(common_english_words, 'ans', None)
+    if ans is None:
+        ans = common_english_words.ans = tuple(x.strip() for x in P('common-english-words.txt', data=True).decode('utf-8').splitlines())
+    return ans
+
+
 def common_user_agents():
     return user_agent_data()['common_user_agents']
 
@@ -39,3 +45,12 @@ def accept_header_for_ua(ua):
     if 'Firefox/' in ua:
         return 'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8'
     return 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8'
+
+
+def common_english_word_ua():
+    words = common_english_words()
+    w1 = random.choice(words)
+    w2 = w1
+    while w2 == w1:
+        w2 = random.choice(words)
+    return f'{w1}/{w2}'
