@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.8
+#!/usr/local/bin/python3.9
 # vim:fileencoding=utf-8
 
 
@@ -47,7 +47,7 @@ def get_compiled_xpath(expr):
         return ans
 
 
-class AlwaysIn(object):
+class AlwaysIn:
 
     def __contains__(self, x):
         return True
@@ -91,7 +91,7 @@ INAPPROPRIATE_PSEUDO_CLASSES = frozenset((
     'active', 'after', 'disabled', 'visited', 'link', 'before', 'focus', 'first-letter', 'enabled', 'first-line', 'hover', 'checked', 'target'))
 
 
-class Select(object):
+class Select:
 
     '''
 
